#
# spec file for package perl-Net-HTTP
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Net-HTTP
Name:           perl-Net-HTTP
Version:        6.23
Release:        1.7
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Low-level HTTP connection (client)
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/O/OA/OALDERS/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Compress::Raw::Zlib)
BuildRequires:  perl(IO::Uncompress::Gunzip)
BuildRequires:  perl(URI)
Requires:       perl(Compress::Raw::Zlib)
Requires:       perl(IO::Uncompress::Gunzip)
Requires:       perl(URI)
%{perl_requires}

%description
The 'Net::HTTP' class is a low-level HTTP client. An instance of the
'Net::HTTP' class represents a connection to an HTTP server. The HTTP
protocol is described in RFC 2616. The 'Net::HTTP' class supports
'HTTP/1.0' and 'HTTP/1.1'.

'Net::HTTP' is a sub-class of one of 'IO::Socket::IP' (IPv6+IPv4),
'IO::Socket::INET6' (IPv6+IPv4), or 'IO::Socket::INET' (IPv4 only). You can
mix the methods described below with reading and writing from the socket
directly. This is not necessary a good idea, unless you know what you are
doing.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes CONTRIBUTORS README.md
%license LICENSE

%changelog
* Sat Jun 17 2023 Tina Müller <timueller+perl@suse.de>
- updated to 6.23
  see /usr/share/doc/packages/perl-Net-HTTP/Changes
  6.23      2023-06-16 11:46:01Z
  - Don't treat HTTP header names as case sensitive in test (GH#81) (Olaf
    Alders)
* Sat Jan 22 2022 Tina Müller <timueller+perl@suse.de>
- updated to 6.22
  see /usr/share/doc/packages/perl-Net-HTTP/Changes
  6.22      2022-01-21 20:41:21Z
  - Format method bullet points as code in docs (GH#77) (Paul Cochrane)
  - Ignore automatically generated directories (GH#76) (Paul Cochrane)
  - Use copyright start year rather than range (issue raised by Paul
    Cochrane)
* Fri Mar 19 2021 Tina Müller <timueller+perl@suse.de>
- updated to 6.21
  see /usr/share/doc/packages/perl-Net-HTTP/Changes
  6.21      2021-03-18 21:56:42Z
  - Accept PeerAddr of 0. (GH#72) (trwyant)
* Mon Jan 11 2021 Dirk Müller <dmueller@suse.com>
- update to 6.20:
  * Replace last use of "vars" with "our" (GH#67) (James Raspass)
* Fri May 17 2019 Stephan Kulow <coolo@suse.com>
- updated to 6.19
  see /usr/share/doc/packages/perl-Net-HTTP/Changes
  6.19      2019-05-16 19:16:59Z
  - partially skip live-https.t if there's no keep-alive connection (GH#58) (Slaven Rezić)
  - set "x_static_install" : 1 in META files
* Thu May 10 2018 coolo@suse.com
- updated to 6.18
  see /usr/share/doc/packages/perl-Net-HTTP/Changes
  6.18      2018-05-09 14:55:43Z
  - Move test that relies on http://httpbin.org to author tests
* Sat Sep  2 2017 coolo@suse.com
- updated to 6.17
  see /usr/share/doc/packages/perl-Net-HTTP/Changes
  6.17      2017-09-01 15:30:20Z
  - Fix test which relied on cpan.org speaking plain HTTP GH#54 (Chase
    Whitener)
* Tue May 30 2017 coolo@suse.com
- updated to 6.16
  see /usr/share/doc/packages/perl-Net-HTTP/Changes
  6.16      2017-05-29 10:46:24-04:00 America/Toronto
  - Bump IO::Socket::SSL version from 1.38 to 2.012
* Tue May 16 2017 coolo@suse.com
- updated to 6.15
  see /usr/share/doc/packages/perl-Net-HTTP/Changes
  6.15      2017-05-12 14:57:02+02:00 Europe/Paris
  - Fix t/rt-112313.t (Shoichi Kaji)
* Tue Apr 25 2017 coolo@suse.com
- updated to 6.14
  see /usr/share/doc/packages/perl-Net-HTTP/Changes
  6.14      2017-04-24 11:27:26-04:00 America/Toronto
  - Improvements to live tests (Shoichi Kaji and Kent Fredric)
  - Fix a bug where downloading files is sometimes very slow GH#44 (Shoichi
    Kaji)
* Mon Feb 20 2017 coolo@suse.com
- updated to 6.13
  see /usr/share/doc/packages/perl-Net-HTTP/Changes
  6.13      2017-02-19 21:40:54-05:00 America/Toronto
  - use EWOULDBLOCK as well on all places where EAGAIN is used (GH PR#24)
* Fri Jan  6 2017 coolo@suse.com
- updated to 6.12
  see /usr/share/doc/packages/perl-Net-HTTP/Changes
  6.12      2017-01-04 23:32:54-05:00 America/Toronto
  - Fix prereqs
* Thu May 21 2015 coolo@suse.com
- updated to 6.09
  see /usr/share/doc/packages/perl-Net-HTTP/Changes
  Release history for Net-HTTP
  _______________________________________________________________________________
  2015-05-20 Net-HTTP 6.09
  Karen Etheridge (1):
    No changes since 6.08_002
  _______________________________________________________________________________
  2015-05-02 Net-HTTP 6.08_002
  Karen Etheridge (1):
    fix foolish $VERSION error in 6.08_001
  _______________________________________________________________________________
  2015-05-01 Net-HTTP 6.08_001
  Mark Overmeer (1):
    resolve issues with SSL by reading bytes still waiting to be read after
    the initial 1024 bytes [RT#104122]
  _______________________________________________________________________________
* Mon Sep 15 2014 coolo@suse.com
- updated to 6.07
  Jason Fesler (1):
    Opportunistically use IO::Socket::IP or IO::Socket::INET6.
    Properly parse IPv6 literal addreses with optional port numbers. [RT#75618]
* Wed Jun  5 2013 coolo@suse.com
- updated to 6.06
    IO::Socket::SSL doesn't play well with select() [RT#81237]
    Convert to Test::More style and disable test on Windows [RT#81090]
* Fri Feb 17 2012 coolo@suse.com
- updated to 6.03
  Restore blocking override for Net::SSL [RT#72790]
  Restore perl-5.6 compatiblity.
* Mon Feb 13 2012 coolo@suse.com
- updated to 6.02
  * Don't disable blocking method [RT#72580]
  * Don't stop on unrecognized Makefile.PL arguments [RT#68337]
  * Document Net:HTTPS [RT#71599]
* Mon Aug 29 2011 chris@computersalat.de
- update to 6.01
  * Don't run live test by default.
    Run 'perl Makefile.PL --live-tests' to enable.
  * More relaxed apache test; should pass even if proxies has added headers.
- fix build for CentOS
  * Unknown tag: Recommends:
* Wed Mar 16 2011 chris@computersalat.de
- fix deps
  o add perl(Compress::Raw::Zlib), perl(IO::Compress::Gzip)
  o Recommends: perl(IO::Socket::SSL) >= 1.38
* Mon Mar 14 2011 vcizek@novell.com
- initial package 6.00
  * created by cpanspec 1.78.03
